""" openconfig_transport_line_protection 

This model describes configuration and operational state data
for optical line protection elements, deployed as part of a
transport line system. An Automatic Protection Switch (APS)
is typically installed in the same device as the amplifiers
and wave\-router, however an APS can also be a standalone
device. In both scenarios, it serves the same purpose of
providing protection using two dark fiber pairs to ensure the
amplifiers can still receive a signal if one of the two fiber
pairs is broken.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class APSPATHS(Identity):
    """
    Base identity for identifying the line paths on an
    automatic protection switch
    
    

    """

    _prefix = 'oc-line-protect'
    _revision = '2017-03-28'

    def __init__(self):
        super(APSPATHS, self).__init__("http://openconfig.net/yang/optical-transport-line-protection", "openconfig-transport-line-protection", "openconfig-transport-line-protection:APS_PATHS")


class Aps(Entity):
    """
    Top level grouping for automatic protection switch data
    
    .. attribute:: aps_modules
    
    	Enclosing container for list of automatic protection switch modules
    	**type**\:   :py:class:`ApsModules <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules>`
    
    

    """

    _prefix = 'oc-line-protect'
    _revision = '2017-03-28'

    def __init__(self):
        super(Aps, self).__init__()
        self._top_entity = None

        self.yang_name = "aps"
        self.yang_parent_name = "openconfig-transport-line-protection"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"aps-modules" : ("aps_modules", Aps.ApsModules)}
        self._child_list_classes = {}

        self.aps_modules = Aps.ApsModules()
        self.aps_modules.parent = self
        self._children_name_map["aps_modules"] = "aps-modules"
        self._children_yang_names.add("aps-modules")
        self._segment_path = lambda: "openconfig-transport-line-protection:aps"


    class ApsModules(Entity):
        """
        Enclosing container for list of automatic protection
        switch modules
        
        .. attribute:: aps_module
        
        	List of automatic protection switch modules present in the device
        	**type**\: list of    :py:class:`ApsModule <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule>`
        
        

        """

        _prefix = 'oc-line-protect'
        _revision = '2017-03-28'

        def __init__(self):
            super(Aps.ApsModules, self).__init__()

            self.yang_name = "aps-modules"
            self.yang_parent_name = "aps"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"aps-module" : ("aps_module", Aps.ApsModules.ApsModule)}

            self.aps_module = YList(self)
            self._segment_path = lambda: "aps-modules"
            self._absolute_path = lambda: "openconfig-transport-line-protection:aps/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Aps.ApsModules, [], name, value)


        class ApsModule(Entity):
            """
            List of automatic protection switch modules present
            in the device
            
            .. attribute:: name  <key>
            
            	Reference to the config name list key
            	**type**\:  str
            
            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Config>`
            
            .. attribute:: config
            
            	Configuration data for an automatic protection switch module
            	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Config>`
            
            .. attribute:: ports
            
            	Top level grouping for automatic protection switch ports
            	**type**\:   :py:class:`Ports <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports>`
            
            .. attribute:: state
            
            	Operational state data for an automatic protection switch module
            	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.State>`
            
            

            """

            _prefix = 'oc-line-protect'
            _revision = '2017-03-28'

            def __init__(self):
                super(Aps.ApsModules.ApsModule, self).__init__()

                self.yang_name = "aps-module"
                self.yang_parent_name = "aps-modules"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"config" : ("config", Aps.ApsModules.ApsModule.Config), "ports" : ("ports", Aps.ApsModules.ApsModule.Ports), "state" : ("state", Aps.ApsModules.ApsModule.State)}
                self._child_list_classes = {}

                self.name = YLeaf(YType.str, "name")

                self.config = Aps.ApsModules.ApsModule.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"
                self._children_yang_names.add("config")

                self.ports = Aps.ApsModules.ApsModule.Ports()
                self.ports.parent = self
                self._children_name_map["ports"] = "ports"
                self._children_yang_names.add("ports")

                self.state = Aps.ApsModules.ApsModule.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"
                self._children_yang_names.add("state")
                self._segment_path = lambda: "aps-module" + "[name='" + self.name.get() + "']"
                self._absolute_path = lambda: "openconfig-transport-line-protection:aps/aps-modules/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Aps.ApsModules.ApsModule, ['name'], name, value)


            class Config(Entity):
                """
                Configuration data for an automatic protection
                switch module
                
                .. attribute:: name
                
                	Reference to the component name (in the platform model) corresponding to this automatic protection switch module in the device
                	**type**\:  str
                
                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_platform.Components.Component>`
                
                .. attribute:: primary_switch_hysteresis
                
                	The delta in 0.01 dB between the primary\-switch\-threshold and the signal received before initiating a reversion in order to prevent toggling between ports when an input signal is very close to threshold. If the hardware supports only one switch hysteresis for primary and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit
                	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                
                	**range:** \-92233720368547758.08..92233720368547758.07
                
                	**units**\: dB
                
                .. attribute:: primary_switch_threshold
                
                	The threshold at which the primary line port will switch to the opposite line port in increments of 0.01 dBm. If the hardware supports only one switch threshold for primary and and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit
                	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                
                	**range:** \-92233720368547758.08..92233720368547758.07
                
                	**units**\: dBm
                
                .. attribute:: revertive
                
                	Revertive behavior of the module. If True, then automatically revert after protection switch once the fault is restored
                	**type**\:  bool
                
                .. attribute:: secondary_switch_hysteresis
                
                	The delta in 0.01 dB between the secondary\-switch\-threshold and the signal received before initiating a reversion in order to prevent toggling between ports when an input signal is very close to threshold. If the hardware supports only one switch hysteresis for primary and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit
                	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                
                	**range:** \-92233720368547758.08..92233720368547758.07
                
                	**units**\: dB
                
                .. attribute:: secondary_switch_threshold
                
                	The threshold at which the secondary line port will switch to the opposite line port in increments of 0.01 dBm. If the hardware supports only one switch threshold for primary and and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit
                	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                
                	**range:** \-92233720368547758.08..92233720368547758.07
                
                	**units**\: dBm
                
                

                """

                _prefix = 'oc-line-protect'
                _revision = '2017-03-28'

                def __init__(self):
                    super(Aps.ApsModules.ApsModule.Config, self).__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "aps-module"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.name = YLeaf(YType.str, "name")

                    self.primary_switch_hysteresis = YLeaf(YType.str, "primary-switch-hysteresis")

                    self.primary_switch_threshold = YLeaf(YType.str, "primary-switch-threshold")

                    self.revertive = YLeaf(YType.boolean, "revertive")

                    self.secondary_switch_hysteresis = YLeaf(YType.str, "secondary-switch-hysteresis")

                    self.secondary_switch_threshold = YLeaf(YType.str, "secondary-switch-threshold")
                    self._segment_path = lambda: "config"

                def __setattr__(self, name, value):
                    self._perform_setattr(Aps.ApsModules.ApsModule.Config, ['name', 'primary_switch_hysteresis', 'primary_switch_threshold', 'revertive', 'secondary_switch_hysteresis', 'secondary_switch_threshold'], name, value)


            class Ports(Entity):
                """
                Top level grouping for automatic protection switch ports
                
                .. attribute:: common_in
                
                	Container for information related to the line common input port
                	**type**\:   :py:class:`CommonIn <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonIn>`
                
                .. attribute:: common_output
                
                	Container for information related to the line common output port
                	**type**\:   :py:class:`CommonOutput <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonOutput>`
                
                .. attribute:: line_primary_in
                
                	Container for information related to the line primary input port
                	**type**\:   :py:class:`LinePrimaryIn <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryIn>`
                
                .. attribute:: line_primary_out
                
                	Container for information related to the line primary output port
                	**type**\:   :py:class:`LinePrimaryOut <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryOut>`
                
                .. attribute:: line_secondary_in
                
                	Container for information related to the line secondary input port
                	**type**\:   :py:class:`LineSecondaryIn <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryIn>`
                
                .. attribute:: line_secondary_out
                
                	Container for information related to the line secondary output port
                	**type**\:   :py:class:`LineSecondaryOut <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryOut>`
                
                

                """

                _prefix = 'oc-line-protect'
                _revision = '2017-03-28'

                def __init__(self):
                    super(Aps.ApsModules.ApsModule.Ports, self).__init__()

                    self.yang_name = "ports"
                    self.yang_parent_name = "aps-module"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"common-in" : ("common_in", Aps.ApsModules.ApsModule.Ports.CommonIn), "common-output" : ("common_output", Aps.ApsModules.ApsModule.Ports.CommonOutput), "line-primary-in" : ("line_primary_in", Aps.ApsModules.ApsModule.Ports.LinePrimaryIn), "line-primary-out" : ("line_primary_out", Aps.ApsModules.ApsModule.Ports.LinePrimaryOut), "line-secondary-in" : ("line_secondary_in", Aps.ApsModules.ApsModule.Ports.LineSecondaryIn), "line-secondary-out" : ("line_secondary_out", Aps.ApsModules.ApsModule.Ports.LineSecondaryOut)}
                    self._child_list_classes = {}

                    self.common_in = Aps.ApsModules.ApsModule.Ports.CommonIn()
                    self.common_in.parent = self
                    self._children_name_map["common_in"] = "common-in"
                    self._children_yang_names.add("common-in")

                    self.common_output = Aps.ApsModules.ApsModule.Ports.CommonOutput()
                    self.common_output.parent = self
                    self._children_name_map["common_output"] = "common-output"
                    self._children_yang_names.add("common-output")

                    self.line_primary_in = Aps.ApsModules.ApsModule.Ports.LinePrimaryIn()
                    self.line_primary_in.parent = self
                    self._children_name_map["line_primary_in"] = "line-primary-in"
                    self._children_yang_names.add("line-primary-in")

                    self.line_primary_out = Aps.ApsModules.ApsModule.Ports.LinePrimaryOut()
                    self.line_primary_out.parent = self
                    self._children_name_map["line_primary_out"] = "line-primary-out"
                    self._children_yang_names.add("line-primary-out")

                    self.line_secondary_in = Aps.ApsModules.ApsModule.Ports.LineSecondaryIn()
                    self.line_secondary_in.parent = self
                    self._children_name_map["line_secondary_in"] = "line-secondary-in"
                    self._children_yang_names.add("line-secondary-in")

                    self.line_secondary_out = Aps.ApsModules.ApsModule.Ports.LineSecondaryOut()
                    self.line_secondary_out.parent = self
                    self._children_name_map["line_secondary_out"] = "line-secondary-out"
                    self._children_yang_names.add("line-secondary-out")
                    self._segment_path = lambda: "ports"


                class CommonIn(Entity):
                    """
                    Container for information related to the line common
                    input port
                    
                    .. attribute:: config
                    
                    	Configuration data for the line common input port
                    	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonIn.Config>`
                    
                    .. attribute:: state
                    
                    	State data for the line common input port
                    	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonIn.State>`
                    
                    

                    """

                    _prefix = 'oc-line-protect'
                    _revision = '2017-03-28'

                    def __init__(self):
                        super(Aps.ApsModules.ApsModule.Ports.CommonIn, self).__init__()

                        self.yang_name = "common-in"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"config" : ("config", Aps.ApsModules.ApsModule.Ports.CommonIn.Config), "state" : ("state", Aps.ApsModules.ApsModule.Ports.CommonIn.State)}
                        self._child_list_classes = {}

                        self.config = Aps.ApsModules.ApsModule.Ports.CommonIn.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"
                        self._children_yang_names.add("config")

                        self.state = Aps.ApsModules.ApsModule.Ports.CommonIn.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "common-in"


                    class Config(Entity):
                        """
                        Configuration data for the line common input port
                        
                        .. attribute:: enabled
                        
                        	This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        	**type**\:  bool
                        
                        	**default value**\: true
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.CommonIn.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "common-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.enabled = YLeaf(YType.boolean, "enabled")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")
                            self._segment_path = lambda: "config"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonIn.Config, ['enabled', 'target_attenuation'], name, value)


                    class State(Entity):
                        """
                        State data for the line common input port
                        
                        .. attribute:: attenuation
                        
                        	The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        .. attribute:: enabled
                        
                        	This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        	**type**\:  bool
                        
                        	**default value**\: true
                        
                        .. attribute:: optical_power
                        
                        	The optical input power of this port in units of 0.01dBm. Optical input power represents the signal traversing from an external destination into the module. The power is measured before any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        	**type**\:   :py:class:`OpticalPower <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower>`
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.CommonIn.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "common-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"optical-power" : ("optical_power", Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower)}
                            self._child_list_classes = {}

                            self.attenuation = YLeaf(YType.str, "attenuation")

                            self.enabled = YLeaf(YType.boolean, "enabled")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._children_yang_names.add("optical-power")
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonIn.State, ['attenuation', 'enabled', 'target_attenuation'], name, value)


                        class OpticalPower(Entity):
                            """
                            The optical input power of this port in units of
                            0.01dBm. Optical input power represents the signal
                            traversing from an external destination into the module.
                            The power is measured before any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: avg
                            
                            	The arithmetic mean value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: instant
                            
                            	The instantaneous value of the statistic
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: max
                            
                            	The maximum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: min
                            
                            	The minimum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            

                            """

                            _prefix = 'oc-line-protect'
                            _revision = '2017-03-28'

                            def __init__(self):
                                super(Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower, self).__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.avg = YLeaf(YType.str, "avg")

                                self.instant = YLeaf(YType.str, "instant")

                                self.max = YLeaf(YType.str, "max")

                                self.min = YLeaf(YType.str, "min")
                                self._segment_path = lambda: "optical-power"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower, ['avg', 'instant', 'max', 'min'], name, value)


                class CommonOutput(Entity):
                    """
                    Container for information related to the line common
                    output port
                    
                    .. attribute:: config
                    
                    	Configuration data for the line common output port
                    	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonOutput.Config>`
                    
                    .. attribute:: state
                    
                    	State data for the line common output port
                    	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonOutput.State>`
                    
                    

                    """

                    _prefix = 'oc-line-protect'
                    _revision = '2017-03-28'

                    def __init__(self):
                        super(Aps.ApsModules.ApsModule.Ports.CommonOutput, self).__init__()

                        self.yang_name = "common-output"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"config" : ("config", Aps.ApsModules.ApsModule.Ports.CommonOutput.Config), "state" : ("state", Aps.ApsModules.ApsModule.Ports.CommonOutput.State)}
                        self._child_list_classes = {}

                        self.config = Aps.ApsModules.ApsModule.Ports.CommonOutput.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"
                        self._children_yang_names.add("config")

                        self.state = Aps.ApsModules.ApsModule.Ports.CommonOutput.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "common-output"


                    class Config(Entity):
                        """
                        Configuration data for the line common output port
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.CommonOutput.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "common-output"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")
                            self._segment_path = lambda: "config"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonOutput.Config, ['target_attenuation'], name, value)


                    class State(Entity):
                        """
                        State data for the line common output port
                        
                        .. attribute:: attenuation
                        
                        	The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        .. attribute:: optical_power
                        
                        	The optical output power of this port in units of 0.01dBm. Optical output power represents the signal traversing from the module to an external destination. The power is measured after any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        	**type**\:   :py:class:`OpticalPower <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower>`
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.CommonOutput.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "common-output"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"optical-power" : ("optical_power", Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower)}
                            self._child_list_classes = {}

                            self.attenuation = YLeaf(YType.str, "attenuation")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._children_yang_names.add("optical-power")
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonOutput.State, ['attenuation', 'target_attenuation'], name, value)


                        class OpticalPower(Entity):
                            """
                            The optical output power of this port in units of
                            0.01dBm. Optical output power represents the signal
                            traversing from the module to an external destination. The
                            power is measured after any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: avg
                            
                            	The arithmetic mean value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: instant
                            
                            	The instantaneous value of the statistic
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: max
                            
                            	The maximum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: min
                            
                            	The minimum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            

                            """

                            _prefix = 'oc-line-protect'
                            _revision = '2017-03-28'

                            def __init__(self):
                                super(Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower, self).__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.avg = YLeaf(YType.str, "avg")

                                self.instant = YLeaf(YType.str, "instant")

                                self.max = YLeaf(YType.str, "max")

                                self.min = YLeaf(YType.str, "min")
                                self._segment_path = lambda: "optical-power"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower, ['avg', 'instant', 'max', 'min'], name, value)


                class LinePrimaryIn(Entity):
                    """
                    Container for information related to the line primary
                    input port
                    
                    .. attribute:: config
                    
                    	Configuration data for the line primary input port
                    	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config>`
                    
                    .. attribute:: state
                    
                    	State data for the line primary input port
                    	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State>`
                    
                    

                    """

                    _prefix = 'oc-line-protect'
                    _revision = '2017-03-28'

                    def __init__(self):
                        super(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn, self).__init__()

                        self.yang_name = "line-primary-in"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"config" : ("config", Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config), "state" : ("state", Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State)}
                        self._child_list_classes = {}

                        self.config = Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"
                        self._children_yang_names.add("config")

                        self.state = Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "line-primary-in"


                    class Config(Entity):
                        """
                        Configuration data for the line primary input port
                        
                        .. attribute:: enabled
                        
                        	This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        	**type**\:  bool
                        
                        	**default value**\: true
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "line-primary-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.enabled = YLeaf(YType.boolean, "enabled")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")
                            self._segment_path = lambda: "config"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config, ['enabled', 'target_attenuation'], name, value)


                    class State(Entity):
                        """
                        State data for the line primary input port
                        
                        .. attribute:: attenuation
                        
                        	The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        .. attribute:: enabled
                        
                        	This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        	**type**\:  bool
                        
                        	**default value**\: true
                        
                        .. attribute:: optical_power
                        
                        	The optical input power of this port in units of 0.01dBm. Optical input power represents the signal traversing from an external destination into the module. The power is measured before any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        	**type**\:   :py:class:`OpticalPower <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower>`
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "line-primary-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"optical-power" : ("optical_power", Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower)}
                            self._child_list_classes = {}

                            self.attenuation = YLeaf(YType.str, "attenuation")

                            self.enabled = YLeaf(YType.boolean, "enabled")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._children_yang_names.add("optical-power")
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State, ['attenuation', 'enabled', 'target_attenuation'], name, value)


                        class OpticalPower(Entity):
                            """
                            The optical input power of this port in units of
                            0.01dBm. Optical input power represents the signal
                            traversing from an external destination into the module.
                            The power is measured before any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: avg
                            
                            	The arithmetic mean value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: instant
                            
                            	The instantaneous value of the statistic
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: max
                            
                            	The maximum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: min
                            
                            	The minimum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            

                            """

                            _prefix = 'oc-line-protect'
                            _revision = '2017-03-28'

                            def __init__(self):
                                super(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower, self).__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.avg = YLeaf(YType.str, "avg")

                                self.instant = YLeaf(YType.str, "instant")

                                self.max = YLeaf(YType.str, "max")

                                self.min = YLeaf(YType.str, "min")
                                self._segment_path = lambda: "optical-power"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower, ['avg', 'instant', 'max', 'min'], name, value)


                class LinePrimaryOut(Entity):
                    """
                    Container for information related to the line primary
                    output port
                    
                    .. attribute:: config
                    
                    	Configuration data for the line primary output port
                    	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config>`
                    
                    .. attribute:: state
                    
                    	State data for the line primary output port
                    	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State>`
                    
                    

                    """

                    _prefix = 'oc-line-protect'
                    _revision = '2017-03-28'

                    def __init__(self):
                        super(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut, self).__init__()

                        self.yang_name = "line-primary-out"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"config" : ("config", Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config), "state" : ("state", Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State)}
                        self._child_list_classes = {}

                        self.config = Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"
                        self._children_yang_names.add("config")

                        self.state = Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "line-primary-out"


                    class Config(Entity):
                        """
                        Configuration data for the line primary output port
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "line-primary-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")
                            self._segment_path = lambda: "config"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config, ['target_attenuation'], name, value)


                    class State(Entity):
                        """
                        State data for the line primary output port
                        
                        .. attribute:: attenuation
                        
                        	The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        .. attribute:: optical_power
                        
                        	The optical output power of this port in units of 0.01dBm. Optical output power represents the signal traversing from the module to an external destination. The power is measured after any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        	**type**\:   :py:class:`OpticalPower <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower>`
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "line-primary-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"optical-power" : ("optical_power", Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower)}
                            self._child_list_classes = {}

                            self.attenuation = YLeaf(YType.str, "attenuation")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._children_yang_names.add("optical-power")
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State, ['attenuation', 'target_attenuation'], name, value)


                        class OpticalPower(Entity):
                            """
                            The optical output power of this port in units of
                            0.01dBm. Optical output power represents the signal
                            traversing from the module to an external destination. The
                            power is measured after any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: avg
                            
                            	The arithmetic mean value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: instant
                            
                            	The instantaneous value of the statistic
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: max
                            
                            	The maximum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: min
                            
                            	The minimum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            

                            """

                            _prefix = 'oc-line-protect'
                            _revision = '2017-03-28'

                            def __init__(self):
                                super(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower, self).__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.avg = YLeaf(YType.str, "avg")

                                self.instant = YLeaf(YType.str, "instant")

                                self.max = YLeaf(YType.str, "max")

                                self.min = YLeaf(YType.str, "min")
                                self._segment_path = lambda: "optical-power"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower, ['avg', 'instant', 'max', 'min'], name, value)


                class LineSecondaryIn(Entity):
                    """
                    Container for information related to the line secondary
                    input port
                    
                    .. attribute:: config
                    
                    	Configuration data for the line secondary input port
                    	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config>`
                    
                    .. attribute:: state
                    
                    	State data for the line secondary input port
                    	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State>`
                    
                    

                    """

                    _prefix = 'oc-line-protect'
                    _revision = '2017-03-28'

                    def __init__(self):
                        super(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn, self).__init__()

                        self.yang_name = "line-secondary-in"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"config" : ("config", Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config), "state" : ("state", Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State)}
                        self._child_list_classes = {}

                        self.config = Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"
                        self._children_yang_names.add("config")

                        self.state = Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "line-secondary-in"


                    class Config(Entity):
                        """
                        Configuration data for the line secondary input port
                        
                        .. attribute:: enabled
                        
                        	This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        	**type**\:  bool
                        
                        	**default value**\: true
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "line-secondary-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.enabled = YLeaf(YType.boolean, "enabled")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")
                            self._segment_path = lambda: "config"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config, ['enabled', 'target_attenuation'], name, value)


                    class State(Entity):
                        """
                        State data for the line secondary input port
                        
                        .. attribute:: attenuation
                        
                        	The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        .. attribute:: enabled
                        
                        	This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        	**type**\:  bool
                        
                        	**default value**\: true
                        
                        .. attribute:: optical_power
                        
                        	The optical input power of this port in units of 0.01dBm. Optical input power represents the signal traversing from an external destination into the module. The power is measured before any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        	**type**\:   :py:class:`OpticalPower <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower>`
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "line-secondary-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"optical-power" : ("optical_power", Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower)}
                            self._child_list_classes = {}

                            self.attenuation = YLeaf(YType.str, "attenuation")

                            self.enabled = YLeaf(YType.boolean, "enabled")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._children_yang_names.add("optical-power")
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State, ['attenuation', 'enabled', 'target_attenuation'], name, value)


                        class OpticalPower(Entity):
                            """
                            The optical input power of this port in units of
                            0.01dBm. Optical input power represents the signal
                            traversing from an external destination into the module.
                            The power is measured before any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: avg
                            
                            	The arithmetic mean value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: instant
                            
                            	The instantaneous value of the statistic
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: max
                            
                            	The maximum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: min
                            
                            	The minimum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            

                            """

                            _prefix = 'oc-line-protect'
                            _revision = '2017-03-28'

                            def __init__(self):
                                super(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower, self).__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.avg = YLeaf(YType.str, "avg")

                                self.instant = YLeaf(YType.str, "instant")

                                self.max = YLeaf(YType.str, "max")

                                self.min = YLeaf(YType.str, "min")
                                self._segment_path = lambda: "optical-power"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower, ['avg', 'instant', 'max', 'min'], name, value)


                class LineSecondaryOut(Entity):
                    """
                    Container for information related to the line secondary
                    output port
                    
                    .. attribute:: config
                    
                    	Configuration data for the line secondary output port
                    	**type**\:   :py:class:`Config <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config>`
                    
                    .. attribute:: state
                    
                    	State data for the line secondary output port
                    	**type**\:   :py:class:`State <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State>`
                    
                    

                    """

                    _prefix = 'oc-line-protect'
                    _revision = '2017-03-28'

                    def __init__(self):
                        super(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut, self).__init__()

                        self.yang_name = "line-secondary-out"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"config" : ("config", Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config), "state" : ("state", Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State)}
                        self._child_list_classes = {}

                        self.config = Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"
                        self._children_yang_names.add("config")

                        self.state = Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "line-secondary-out"


                    class Config(Entity):
                        """
                        Configuration data for the line secondary output port
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "line-secondary-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")
                            self._segment_path = lambda: "config"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config, ['target_attenuation'], name, value)


                    class State(Entity):
                        """
                        State data for the line secondary output port
                        
                        .. attribute:: attenuation
                        
                        	The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        .. attribute:: optical_power
                        
                        	The optical output power of this port in units of 0.01dBm. Optical output power represents the signal traversing from the module to an external destination. The power is measured after any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        	**type**\:   :py:class:`OpticalPower <ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower>`
                        
                        .. attribute:: target_attenuation
                        
                        	Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                        	**range:** \-92233720368547758.08..92233720368547758.07
                        
                        	**units**\: dB
                        
                        

                        """

                        _prefix = 'oc-line-protect'
                        _revision = '2017-03-28'

                        def __init__(self):
                            super(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "line-secondary-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"optical-power" : ("optical_power", Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower)}
                            self._child_list_classes = {}

                            self.attenuation = YLeaf(YType.str, "attenuation")

                            self.target_attenuation = YLeaf(YType.str, "target-attenuation")

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._children_yang_names.add("optical-power")
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State, ['attenuation', 'target_attenuation'], name, value)


                        class OpticalPower(Entity):
                            """
                            The optical output power of this port in units of
                            0.01dBm. Optical output power represents the signal
                            traversing from the module to an external destination. The
                            power is measured after any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: avg
                            
                            	The arithmetic mean value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: instant
                            
                            	The instantaneous value of the statistic
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: max
                            
                            	The maximum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            .. attribute:: min
                            
                            	The minimum value of the statistic over the sampling period
                            	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                            	**range:** \-92233720368547758.08..92233720368547758.07
                            
                            	**units**\: dBm
                            
                            

                            """

                            _prefix = 'oc-line-protect'
                            _revision = '2017-03-28'

                            def __init__(self):
                                super(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower, self).__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.avg = YLeaf(YType.str, "avg")

                                self.instant = YLeaf(YType.str, "instant")

                                self.max = YLeaf(YType.str, "max")

                                self.min = YLeaf(YType.str, "min")
                                self._segment_path = lambda: "optical-power"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower, ['avg', 'instant', 'max', 'min'], name, value)


            class State(Entity):
                """
                Operational state data for an automatic protection
                switch module
                
                .. attribute:: active_path
                
                	Indicates which line path on the automatic protection switch is currently the active path connected to the common port
                	**type**\:   :py:class:`APSPATHS <ydk.models.openconfig.openconfig_transport_line_protection.APSPATHS>`
                
                .. attribute:: name
                
                	Reference to the component name (in the platform model) corresponding to this automatic protection switch module in the device
                	**type**\:  str
                
                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_platform.Components.Component>`
                
                .. attribute:: primary_switch_hysteresis
                
                	The delta in 0.01 dB between the primary\-switch\-threshold and the signal received before initiating a reversion in order to prevent toggling between ports when an input signal is very close to threshold. If the hardware supports only one switch hysteresis for primary and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit
                	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                
                	**range:** \-92233720368547758.08..92233720368547758.07
                
                	**units**\: dB
                
                .. attribute:: primary_switch_threshold
                
                	The threshold at which the primary line port will switch to the opposite line port in increments of 0.01 dBm. If the hardware supports only one switch threshold for primary and and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit
                	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                
                	**range:** \-92233720368547758.08..92233720368547758.07
                
                	**units**\: dBm
                
                .. attribute:: revertive
                
                	Revertive behavior of the module. If True, then automatically revert after protection switch once the fault is restored
                	**type**\:  bool
                
                .. attribute:: secondary_switch_hysteresis
                
                	The delta in 0.01 dB between the secondary\-switch\-threshold and the signal received before initiating a reversion in order to prevent toggling between ports when an input signal is very close to threshold. If the hardware supports only one switch hysteresis for primary and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit
                	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                
                	**range:** \-92233720368547758.08..92233720368547758.07
                
                	**units**\: dB
                
                .. attribute:: secondary_switch_threshold
                
                	The threshold at which the secondary line port will switch to the opposite line port in increments of 0.01 dBm. If the hardware supports only one switch threshold for primary and and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit
                	**type**\:  :py:class:`Decimal64<ydk.types.Decimal64>`
                
                	**range:** \-92233720368547758.08..92233720368547758.07
                
                	**units**\: dBm
                
                

                """

                _prefix = 'oc-line-protect'
                _revision = '2017-03-28'

                def __init__(self):
                    super(Aps.ApsModules.ApsModule.State, self).__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "aps-module"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.active_path = YLeaf(YType.identityref, "active-path")

                    self.name = YLeaf(YType.str, "name")

                    self.primary_switch_hysteresis = YLeaf(YType.str, "primary-switch-hysteresis")

                    self.primary_switch_threshold = YLeaf(YType.str, "primary-switch-threshold")

                    self.revertive = YLeaf(YType.boolean, "revertive")

                    self.secondary_switch_hysteresis = YLeaf(YType.str, "secondary-switch-hysteresis")

                    self.secondary_switch_threshold = YLeaf(YType.str, "secondary-switch-threshold")
                    self._segment_path = lambda: "state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Aps.ApsModules.ApsModule.State, ['active_path', 'name', 'primary_switch_hysteresis', 'primary_switch_threshold', 'revertive', 'secondary_switch_hysteresis', 'secondary_switch_threshold'], name, value)

    def clone_ptr(self):
        self._top_entity = Aps()
        return self._top_entity

class PRIMARY(Identity):
    """
    The primary line path connected to an automatic protection
    switch port indicating the primary/preferred path
    
    

    """

    _prefix = 'oc-line-protect'
    _revision = '2017-03-28'

    def __init__(self):
        super(PRIMARY, self).__init__("http://openconfig.net/yang/optical-transport-line-protection", "openconfig-transport-line-protection", "openconfig-transport-line-protection:PRIMARY")


class SECONDARY(Identity):
    """
    The secondary line path connected to an automatic protection
    switch port indicating the secondary path
    
    

    """

    _prefix = 'oc-line-protect'
    _revision = '2017-03-28'

    def __init__(self):
        super(SECONDARY, self).__init__("http://openconfig.net/yang/optical-transport-line-protection", "openconfig-transport-line-protection", "openconfig-transport-line-protection:SECONDARY")





""" openconfig_transport_types 

This module contains general type definitions and identities
for optical transport models.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class AdminStateType(Enum):
    """
    AdminStateType

    Administrative state modes for

    logical channels in the transponder model.

    .. data:: ENABLED = 0

    	Sets the channel admin state to enabled

    .. data:: DISABLED = 1

    	Sets the channel admin state to disabled

    .. data:: MAINT = 2

    	Sets the channel to maintenance / diagnostic mode

    """

    ENABLED = Enum.YLeaf(0, "ENABLED")

    DISABLED = Enum.YLeaf(1, "DISABLED")

    MAINT = Enum.YLeaf(2, "MAINT")


class LoopbackModeType(Enum):
    """
    LoopbackModeType

    Loopback modes for transponder logical channels

    .. data:: NONE = 0

    	No loopback is applied

    .. data:: FACILITY = 1

    	A loopback which directs traffic normally transmitted

    	on the port back to the device as if received on the same

    	port from an external source.

    .. data:: TERMINAL = 2

    	A loopback which directs traffic received from an external

    	source on the port back out the transmit side of the same

    	port.

    """

    NONE = Enum.YLeaf(0, "NONE")

    FACILITY = Enum.YLeaf(1, "FACILITY")

    TERMINAL = Enum.YLeaf(2, "TERMINAL")



class ETHERNETPMDTYPE(Identity):
    """
    Ethernet compliance codes (PMD) supported by transceivers
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETHERNETPMDTYPE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETHERNET_PMD_TYPE")


class FIBERCONNECTORTYPE(Identity):
    """
    Type of optical fiber connector
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(FIBERCONNECTORTYPE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:FIBER_CONNECTOR_TYPE")


class LOGICALELEMENTPROTOCOLTYPE(Identity):
    """
    Type of protocol framing used on the logical channel or
    tributary
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(LOGICALELEMENTPROTOCOLTYPE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:LOGICAL_ELEMENT_PROTOCOL_TYPE")


class OPTICALCHANNEL(Identity):
    """
    Optical channels act as carriers for transport traffic
    directed over a line system.  They are represented as
    physical components in the physical inventory model.
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(OPTICALCHANNEL, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:OPTICAL_CHANNEL")


class OTNAPPLICATIONCODE(Identity):
    """
    Supported OTN application codes
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(OTNAPPLICATIONCODE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:OTN_APPLICATION_CODE")


class SONETAPPLICATIONCODE(Identity):
    """
    Supported SONET/SDH application codes
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(SONETAPPLICATIONCODE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:SONET_APPLICATION_CODE")


class TRANSCEIVERFORMFACTORTYPE(Identity):
    """
    Base identity for identifying the type of pluggable optic
    transceiver (i.e,. form factor) used in a port.
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(TRANSCEIVERFORMFACTORTYPE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:TRANSCEIVER_FORM_FACTOR_TYPE")


class TRIBUTARYPROTOCOLTYPE(Identity):
    """
    Base identity for protocol framing used by tributary
    signals.
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(TRIBUTARYPROTOCOLTYPE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:TRIBUTARY_PROTOCOL_TYPE")


class TRIBUTARYRATECLASSTYPE(Identity):
    """
    Rate of tributary signal \_\- identities will typically reflect
    rounded bit rate.
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(TRIBUTARYRATECLASSTYPE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:TRIBUTARY_RATE_CLASS_TYPE")


class CFP(Identity):
    """
    C form\-factor pluggable, that can support up to a
    100 Gb/s signal with 10x10G or 4x25G physical channels
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(CFP, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:CFP")


class CFP2(Identity):
    """
    1/2 C form\-factor pluggable, that can support up to a
    200 Gb/s signal with 10x10G, 4x25G, or 8x25G physical
    channels
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(CFP2, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:CFP2")


class CFP2ACO(Identity):
    """
    CFP2 analog coherent optics transceiver, supporting
    100 Gb, 200Gb, and 250 Gb/s signal.
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(CFP2ACO, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:CFP2_ACO")


class CFP4(Identity):
    """
    1/4 C form\-factor pluggable, that can support up to a
    100 Gb/s signal with 10x10G or 4x25G physical channels
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(CFP4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:CFP4")


class ETH100GACC(Identity):
    """
    Ethernet compliance code\: 100G\_ACC
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GACC, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100G_ACC")


class ETH100GAOC(Identity):
    """
    Ethernet compliance code\: 100G\_AOC
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GAOC, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100G_AOC")


class ETH100GBASECLR4(Identity):
    """
    Ethernet compliance code\: 100GBASE\_CLR4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GBASECLR4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100GBASE_CLR4")


class ETH100GBASECR4(Identity):
    """
    Ethernet compliance code\: 100GBASE\_CR4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GBASECR4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100GBASE_CR4")


class ETH100GBASECWDM4(Identity):
    """
    Ethernet compliance code\: 100GBASE\_CWDM4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GBASECWDM4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100GBASE_CWDM4")


class ETH100GBASEER4(Identity):
    """
    Ethernet compliance code\: 100GBASE\_ER4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GBASEER4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100GBASE_ER4")


class ETH100GBASELR4(Identity):
    """
    Ethernet compliance code\: 100GBASE\_LR4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GBASELR4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100GBASE_LR4")


class ETH100GBASEPSM4(Identity):
    """
    Ethernet compliance code\: 100GBASE\_PSM4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GBASEPSM4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100GBASE_PSM4")


class ETH100GBASESR10(Identity):
    """
    Ethernet compliance code\: 100GBASE\_SR10
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GBASESR10, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100GBASE_SR10")


class ETH100GBASESR4(Identity):
    """
    Ethernet compliance code\: 100GBASE\_SR4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH100GBASESR4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_100GBASE_SR4")


class ETH10GBASEER(Identity):
    """
    Ethernet compliance code\: 10GBASE\_ER
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH10GBASEER, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_10GBASE_ER")


class ETH10GBASELR(Identity):
    """
    Ethernet compliance code\: 10GBASE\_LR
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH10GBASELR, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_10GBASE_LR")


class ETH10GBASELRM(Identity):
    """
    Ethernet compliance code\: 10GBASE\_LRM
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH10GBASELRM, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_10GBASE_LRM")


class ETH10GBASESR(Identity):
    """
    Ethernet compliance code\: 10GBASE\_SR
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH10GBASESR, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_10GBASE_SR")


class ETH10GBASEZR(Identity):
    """
    Ethernet compliance code\: 10GBASE\_ZR
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH10GBASEZR, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_10GBASE_ZR")


class ETH40GBASECR4(Identity):
    """
    Ethernet compliance code\: 40GBASE\_CR4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH40GBASECR4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_40GBASE_CR4")


class ETH40GBASEER4(Identity):
    """
    Ethernet compliance code\: 40GBASE\_ER4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH40GBASEER4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_40GBASE_ER4")


class ETH40GBASELR4(Identity):
    """
    Ethernet compliance code\: 40GBASE\_LR4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH40GBASELR4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_40GBASE_LR4")


class ETH40GBASEPSM4(Identity):
    """
    Ethernet compliance code\: 40GBASE\_PSM4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH40GBASEPSM4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_40GBASE_PSM4")


class ETH40GBASESR4(Identity):
    """
    Ethernet compliance code\: 40GBASE\_SR4
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH40GBASESR4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_40GBASE_SR4")


class ETH4X10GBASELR(Identity):
    """
    Ethernet compliance code\: 4x10GBASE\_LR
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH4X10GBASELR, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_4X10GBASE_LR")


class ETH4X10GBASESR(Identity):
    """
    Ethernet compliance code\: 4x10GBASE\_SR
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETH4X10GBASESR, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_4X10GBASE_SR")


class ETHUNDEFINED(Identity):
    """
    Ethernet compliance code\: undefined
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(ETHUNDEFINED, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:ETH_UNDEFINED")


class LCCONNECTOR(Identity):
    """
    LC type fiber connector
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(LCCONNECTOR, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:LC_CONNECTOR")


class MPOCONNECTOR(Identity):
    """
    MPO (multi\-fiber push\-on/pull\-off) type fiber connector
    1x12 fibers
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(MPOCONNECTOR, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:MPO_CONNECTOR")


class NONPLUGGABLE(Identity):
    """
    Represents a port that does not require a pluggable optic,
    e.g., with on\-board optics like COBO
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(NONPLUGGABLE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:NON_PLUGGABLE")


class OTHER(Identity):
    """
    Represents a transceiver form factor not otherwise listed
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(OTHER, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:OTHER")


class OTNUNDEFINED(Identity):
    """
    OTN application code\: undefined
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(OTNUNDEFINED, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:OTN_UNDEFINED")


class P1L12D1(Identity):
    """
    OTN application code\: P1L1\_2D1
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(P1L12D1, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:P1L1_2D1")


class P1L12D2(Identity):
    """
    OTN application code\: P1L1\_2D2
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(P1L12D2, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:P1L1_2D2")


class P1S12D2(Identity):
    """
    OTN application code\: P1S1\_2D2
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(P1S12D2, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:P1S1_2D2")


class PROT100GE(Identity):
    """
    100G Ethernet protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROT100GE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_100GE")


class PROT100GMLG(Identity):
    """
    100G MLG protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROT100GMLG, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_100G_MLG")


class PROT10GELAN(Identity):
    """
    10G Ethernet LAN protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROT10GELAN, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_10GE_LAN")


class PROT10GEWAN(Identity):
    """
    10G Ethernet WAN protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROT10GEWAN, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_10GE_WAN")


class PROT1GE(Identity):
    """
    1G Ethernet protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROT1GE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_1GE")


class PROT40GE(Identity):
    """
    40G Ethernet port protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROT40GE, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_40GE")


class PROTETHERNET(Identity):
    """
    Ethernet protocol framing
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTETHERNET, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_ETHERNET")


class PROTOC192(Identity):
    """
    OC 192 (9.6GB) port protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOC192, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OC192")


class PROTOC48(Identity):
    """
    OC48 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOC48, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OC48")


class PROTOC768(Identity):
    """
    OC 768 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOC768, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OC768")


class PROTODU2(Identity):
    """
    ODU 2 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTODU2, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_ODU2")


class PROTODU2E(Identity):
    """
    ODU 2e protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTODU2E, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_ODU2E")


class PROTODU3(Identity):
    """
    ODU 3 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTODU3, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_ODU3")


class PROTODU4(Identity):
    """
    ODU 4 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTODU4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_ODU4")


class PROTOTN(Identity):
    """
    OTN protocol framing
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOTN, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OTN")


class PROTOTU1E(Identity):
    """
    OTU 1e protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOTU1E, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OTU1E")


class PROTOTU2(Identity):
    """
    OTU 2 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOTU2, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OTU2")


class PROTOTU2E(Identity):
    """
    OTU 2e protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOTU2E, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OTU2E")


class PROTOTU3(Identity):
    """
    OTU 3 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOTU3, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OTU3")


class PROTOTU4(Identity):
    """
    OTU4 signal protocol (112G) for transporting
    100GE signal
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOTU4, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OTU4")


class PROTOTUCN(Identity):
    """
    OTU Cn protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTOTUCN, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_OTUCN")


class PROTSTM16(Identity):
    """
    STM 16 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTSTM16, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_STM16")


class PROTSTM256(Identity):
    """
    STM 256 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTSTM256, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_STM256")


class PROTSTM64(Identity):
    """
    STM 64 protocol
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(PROTSTM64, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:PROT_STM64")


class QSFP(Identity):
    """
    Quad Small Form\-factor Pluggable transceiver that can support
    up to 4x10G physical channels
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(QSFP, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:QSFP")


class QSFP28(Identity):
    """
    QSFP pluggable optic with support for up to 4x28G physical
    channels
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(QSFP28, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:QSFP28")


class SCCONNECTOR(Identity):
    """
    SC type fiber connector
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(SCCONNECTOR, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:SC_CONNECTOR")


class SFP(Identity):
    """
    Small form\-factor pluggable transceiver supporting up to
    10 Gb/s signal
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(SFP, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:SFP")


class SFPPLUS(Identity):
    """
    Enhanced small form\-factor pluggable transceiver supporting
    up to 16 Gb/s signals, including 10 GbE and OTU2
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(SFPPLUS, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:SFP_PLUS")


class SONETUNDEFINED(Identity):
    """
    SONET/SDH application code\: undefined
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(SONETUNDEFINED, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:SONET_UNDEFINED")


class TRIBRATE100G(Identity):
    """
    100G tributary signal rate
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(TRIBRATE100G, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:TRIB_RATE_100G")


class TRIBRATE10G(Identity):
    """
    10G tributary signal rate
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(TRIBRATE10G, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:TRIB_RATE_10G")


class TRIBRATE1G(Identity):
    """
    1G tributary signal rate
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(TRIBRATE1G, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:TRIB_RATE_1G")


class TRIBRATE2DOT5G(Identity):
    """
    2.5G tributary signal rate
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(TRIBRATE2DOT5G, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:TRIB_RATE_2.5G")


class TRIBRATE40G(Identity):
    """
    40G tributary signal rate
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(TRIBRATE40G, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:TRIB_RATE_40G")


class VSR20003R2(Identity):
    """
    SONET/SDH application code\: VSR2000\_3R2
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(VSR20003R2, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:VSR2000_3R2")


class VSR20003R3(Identity):
    """
    SONET/SDH application code\: VSR2000\_3R3
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(VSR20003R3, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:VSR2000_3R3")


class VSR20003R5(Identity):
    """
    SONET/SDH application code\: VSR2000\_3R5
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(VSR20003R5, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:VSR2000_3R5")


class X2(Identity):
    """
    10 Gigabit small form factor pluggable transceiver supporting
    10 GbE using a XAUI inerface and 4 data channels.
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(X2, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:X2")


class XFP(Identity):
    """
    10 Gigabit small form factor pluggable transceiver supporting
    10 GbE and OTU2
    
    

    """

    _prefix = 'oc-opt-types'
    _revision = '2016-06-17'

    def __init__(self):
        super(XFP, self).__init__("http://openconfig.net/yang/transport-types", "openconfig-transport-types", "openconfig-transport-types:XFP")





BUNDLE_NAME = "openconfig"

CAPABILITIES = {
    "cisco-xr-openconfig-interfaces-types": "2016-10-12",
    "openconfig-bgp": "2016-06-21",
    "openconfig-bgp-common": "2016-06-21",
    "openconfig-bgp-common-multiprotocol": "2016-06-21",
    "openconfig-bgp-common-structure": "2016-06-21",
    "openconfig-bgp-global": "2016-06-21",
    "openconfig-bgp-neighbor": "2016-06-21",
    "openconfig-bgp-peer-group": "2016-06-21",
    "openconfig-bgp-policy": "2016-06-21",
    "openconfig-bgp-types": "2016-06-21",
    "openconfig-channel-monitor": "2017-07-08",
    "openconfig-extensions": "2015-10-09",
    "openconfig-if-aggregate": "2016-05-26",
    "openconfig-if-ethernet": "2016-05-26",
    "openconfig-if-ip": "2016-05-26",
    "openconfig-interfaces": "2016-05-26",
    "openconfig-lacp": "2016-05-26",
    "openconfig-local-routing": "2016-05-11",
    "openconfig-mpls": "2015-11-05",
    "openconfig-mpls-igp": "2015-11-05",
    "openconfig-mpls-ldp": "2015-11-05",
    "openconfig-mpls-rsvp": "2015-11-05",
    "openconfig-mpls-sr": "2015-11-05",
    "openconfig-mpls-static": "2015-11-05",
    "openconfig-mpls-te": "2015-11-05",
    "openconfig-mpls-types": "2015-11-05",
    "openconfig-optical-amplifier": "2017-07-08",
    "openconfig-platform": "2016-06-06",
    "openconfig-platform-transceiver": "2016-05-24",
    "openconfig-platform-types": "2016-06-06",
    "openconfig-policy-types": "2016-05-12",
    "openconfig-rib-bgp": "2016-04-11",
    "openconfig-rib-bgp-types": "2016-04-11",
    "openconfig-routing-policy": "2016-05-12",
    "openconfig-telemetry": "2016-02-04",
    "openconfig-terminal-device": "2016-06-17",
    "openconfig-transport-line-common": "2017-07-08",
    "openconfig-transport-line-protection": "2017-03-28",
    "openconfig-transport-types": "2016-06-17",
    "openconfig-types": "2017-01-13",
    "openconfig-vlan": "2016-05-26",
    "openconfig-vlan-types": "2016-05-26",
}

ENTITY_LOOKUP = {
    ("http://openconfig.net/yang/bgp", "bgp"): "openconfig_bgp.Bgp",
    ("openconfig-bgp", "bgp"): "openconfig_bgp.Bgp",
    ("http://openconfig.net/yang/channel-monitor", "channel-monitors"): "openconfig_channel_monitor.ChannelMonitors",
    ("openconfig-channel-monitor", "channel-monitors"): "openconfig_channel_monitor.ChannelMonitors",
    ("http://openconfig.net/yang/interfaces", "interfaces"): "openconfig_interfaces.Interfaces",
    ("openconfig-interfaces", "interfaces"): "openconfig_interfaces.Interfaces",
    ("http://openconfig.net/yang/lacp", "lacp"): "openconfig_lacp.Lacp",
    ("openconfig-lacp", "lacp"): "openconfig_lacp.Lacp",
    ("http://openconfig.net/yang/local-routing", "local-routes"): "openconfig_local_routing.LocalRoutes",
    ("openconfig-local-routing", "local-routes"): "openconfig_local_routing.LocalRoutes",
    ("http://openconfig.net/yang/mpls", "mpls"): "openconfig_mpls.Mpls",
    ("openconfig-mpls", "mpls"): "openconfig_mpls.Mpls",
    ("http://openconfig.net/yang/optical-amplfier", "optical-amplifier"): "openconfig_optical_amplifier.OpticalAmplifier",
    ("openconfig-optical-amplifier", "optical-amplifier"): "openconfig_optical_amplifier.OpticalAmplifier",
    ("http://openconfig.net/yang/platform", "components"): "openconfig_platform.Components",
    ("openconfig-platform", "components"): "openconfig_platform.Components",
    ("http://openconfig.net/yang/rib/bgp", "bgp-rib"): "openconfig_rib_bgp.BgpRib",
    ("openconfig-rib-bgp", "bgp-rib"): "openconfig_rib_bgp.BgpRib",
    ("http://openconfig.net/yang/routing-policy", "routing-policy"): "openconfig_routing_policy.RoutingPolicy",
    ("openconfig-routing-policy", "routing-policy"): "openconfig_routing_policy.RoutingPolicy",
    ("http://openconfig.net/yang/telemetry", "telemetry-system"): "openconfig_telemetry.TelemetrySystem",
    ("openconfig-telemetry", "telemetry-system"): "openconfig_telemetry.TelemetrySystem",
    ("http://openconfig.net/yang/terminal-device", "terminal-device"): "openconfig_terminal_device.TerminalDevice",
    ("openconfig-terminal-device", "terminal-device"): "openconfig_terminal_device.TerminalDevice",
    ("http://openconfig.net/yang/optical-transport-line-protection", "aps"): "openconfig_transport_line_protection.Aps",
    ("openconfig-transport-line-protection", "aps"): "openconfig_transport_line_protection.Aps",
    ("http://openconfig.net/yang/vlan", "vlans"): "openconfig_vlan.Vlans",
    ("openconfig-vlan", "vlans"): "openconfig_vlan.Vlans",
}

NAMESPACE_LOOKUP = {
    "cisco-xr-openconfig-interfaces-types": "http://cisco.com/ns/yang/cisco-xr-openconfig-interfaces-types",
    "openconfig-bgp": "http://openconfig.net/yang/bgp",
    "openconfig-bgp-policy": "http://openconfig.net/yang/bgp-policy",
    "openconfig-bgp-types": "http://openconfig.net/yang/bgp-types",
    "openconfig-channel-monitor": "http://openconfig.net/yang/channel-monitor",
    "openconfig-extensions": "http://openconfig.net/yang/openconfig-ext",
    "openconfig-if-aggregate": "http://openconfig.net/yang/interfaces/aggregate",
    "openconfig-if-ethernet": "http://openconfig.net/yang/interfaces/ethernet",
    "openconfig-if-ip": "http://openconfig.net/yang/interfaces/ip",
    "openconfig-interfaces": "http://openconfig.net/yang/interfaces",
    "openconfig-lacp": "http://openconfig.net/yang/lacp",
    "openconfig-local-routing": "http://openconfig.net/yang/local-routing",
    "openconfig-mpls": "http://openconfig.net/yang/mpls",
    "openconfig-mpls-ldp": "http://openconfig.net/yang/ldp",
    "openconfig-mpls-rsvp": "http://openconfig.net/yang/rsvp",
    "openconfig-mpls-sr": "http://openconfig.net/yang/sr",
    "openconfig-mpls-types": "http://openconfig.net/yang/mpls-types",
    "openconfig-optical-amplifier": "http://openconfig.net/yang/optical-amplfier",
    "openconfig-platform": "http://openconfig.net/yang/platform",
    "openconfig-platform-transceiver": "http://openconfig.net/yang/platform/transceiver",
    "openconfig-platform-types": "http://openconfig.net/yang/platform-types",
    "openconfig-policy-types": "http://openconfig.net/yang/policy-types",
    "openconfig-rib-bgp": "http://openconfig.net/yang/rib/bgp",
    "openconfig-rib-bgp-types": "http://openconfig.net/yang/rib/bgp-types",
    "openconfig-routing-policy": "http://openconfig.net/yang/routing-policy",
    "openconfig-telemetry": "http://openconfig.net/yang/telemetry",
    "openconfig-terminal-device": "http://openconfig.net/yang/terminal-device",
    "openconfig-transport-line-common": "http://openconfig.net/yang/transport-line-common",
    "openconfig-transport-line-protection": "http://openconfig.net/yang/optical-transport-line-protection",
    "openconfig-transport-types": "http://openconfig.net/yang/transport-types",
    "openconfig-types": "http://openconfig.net/yang/openconfig-types",
    "openconfig-vlan": "http://openconfig.net/yang/vlan",
    "openconfig-vlan-types": "http://openconfig.net/yang/vlan-types",
}

